@@ -231,10 +231,7 @@ module Kramdown
       # ID.
       def generate_id(str)
         str = ::Kramdown::Utils::Unidecoder.decode(str) if @options[:transliterated_header_ids]
-        gen_id = str.gsub(/^[^a-zA-Z]+/, '')
-        gen_id.tr!('^a-zA-Z0-9 -', '')
-        gen_id.tr!(' ', '-')
-        gen_id.downcase!
+        gen_id = basic_generate_id(str)
         gen_id = 'section' if gen_id.length == 0
         @used_ids ||= {}
         if @used_ids.has_key?(gen_id)
@@ -245,6 +242,16 @@ module Kramdown
         @options[:auto_id_prefix] + gen_id
       end
 
+      # The basic version of the ID generator, without any special provisions for empty or unique
+      # IDs.
+      def basic_generate_id(str)
+        gen_id = str.gsub(/^[^a-zA-Z]+/, '')
+        gen_id.tr!('^a-zA-Z0-9 -', '')
+        gen_id.tr!(' ', '-')
+        gen_id.downcase!
+        gen_id
+      end
+
       SMART_QUOTE_INDICES = {:lsquo => 0, :rsquo => 1, :ldquo => 2, :rdquo => 3} # :nodoc:
 
       # Return the entity that represents the given smart_quote element.
