@@ -166,6 +166,11 @@ module Kramdown
         deflist.options[:location] = para.options[:location] # take location from preceding para which is the first definition term
         para.children.first.value.split(/\n/).each do |term|
           el = Element.new(:dt, nil, nil, :location => @src.current_line_number)
+          term.sub!(self.class::LIST_ITEM_IAL) do
+            parse_attribute_list($1, el.options[:ial] ||= {})
+            ''
+          end
+          el.options[:raw_text] = term
           el.children << Element.new(:raw_text, term)
           deflist.children << el
         end
